==> enterprisemodules-ora_config-3.20.0.tar.gz: enterprisemodules-ora_config-3.20.0/tasks/insert_data_dp.rb <==
# rubocop:disable Style/FrozenStringLiteralComment
# !/opt/puppetlabs/puppet/bin/ruby
#
# See the file "LICENSE" for the full license governing this code.
#
require 'json'
require 'puppet'

begin
  Puppet.initialize_settings
rescue Puppet::DevError
  # When run in Rspec, this is called multiple times
end

begin
  # TODO: import pluggable database
  params = JSON.parse($stdin.read)
  sid                    = params.fetch('sid')
  oracle_home            = params.fetch('oracle_home')
  # TODO: check if that is needed
  # rubocop:disable Lint/UselessAssignment
  cdb                    = params.fetch('cdb')
  pluggable              = params.fetch('pluggable')
  contained_by           = params.fetch('contained_by')
  # rubocop:enable Lint/UselessAssignment
  database_user          = params.fetch('database_user', '')
  database_user_password = params.fetch('database_user_password', '')
  os_user                = params.fetch('os_user')
  directory              = params.fetch('directory')
  $LOAD_PATH << "#{params['_installdir']}/easy_type/lib"
  $LOAD_PATH << "#{params['_installdir']}/ora_config/lib"
  require 'easy_type'
  require 'puppet_x/enterprisemodules/oracle/access'
  include Puppet_X::EnterpriseModules::Oracle::Access

  # Create directory in database:
  directory_name = 'EXTRACT_DATA_DP'
  result = sql("create or replace directory #{directory_name} as '#{directory}'", { :sid => sid })
  puts({ :step => 'create directory', :status => 'success', :output => result }.to_json)

  # Export database
  connect_string = if database_user.empty?
                     '/ as sysdba'
                   else
                     "#{database_user}/#{database_user_password}"
                   end
  dumpfile = "#{directory_name}_#{sid}.dmp"
  logfile = "impdp_#{directory_name}_#{sid}.log"
  environment = {}
  environment[:ORACLE_HOME] = oracle_home
  environment[:ORACLE_SID] = sid
  environment[:PATH] = "/usr/local/bin:/bin:/usr/bin:/usr/local/sbin:/usr/sbin:/sbin:#{oracle_home}/bin"
  command = "echo #{connect_string} | #{oracle_home}/bin/impdp directory=#{directory_name} dumpfile=#{dumpfile} logfile=#{logfile} full=yes"
  result = Puppet::Util::Execution.execute(command, :failonfail => true, :custom_environment => environment, :uid => os_user)
  puts({ :step => 'import', :status => 'success', :output => result }.to_json)

  # Remove the directory
  result = sql("drop directory #{directory_name}", { :sid => sid })
  puts({ :step => 'remove directory', :status => 'success', :output => result }.to_json)
rescue Puppet::Error => e
  puts({ :status => 'failure', :error => e.message }.to_json)
  exit 1
end
# rubocop:enable Style/FrozenStringLiteralComment

==> enterprisemodules-ora_config-3.25.0.tar.gz: enterprisemodules-ora_config-3.25.0/tasks/insert_data_dp.rb <==
# rubocop:disable Style/FrozenStringLiteralComment
# !/opt/puppetlabs/puppet/bin/ruby
#
# See the file "LICENSE" for the full license governing this code.
#
require 'json'
require 'puppet'

begin
  Puppet.initialize_settings
rescue Puppet::DevError
  # When run in Rspec, this is called multiple times
end

begin
  # TODO: import pluggable database
  params = JSON.parse($stdin.read)
  sid                    = params.fetch('sid')
  oracle_home            = params.fetch('oracle_home')
  # TODO: check if that is needed
  # rubocop:disable Lint/UselessAssignment
  cdb                    = params.fetch('cdb')
  pluggable              = params.fetch('pluggable')
  contained_by           = params.fetch('contained_by')
  # rubocop:enable Lint/UselessAssignment
  database_user          = params.fetch('database_user', '')
  database_user_password = params.fetch('database_user_password', '')
  os_user                = params.fetch('os_user')
  directory              = params.fetch('directory')
  $LOAD_PATH << "#{params['_installdir']}/easy_type/lib"
  $LOAD_PATH << "#{params['_installdir']}/ora_config/lib"
  require 'easy_type'
  require 'puppet_x/enterprisemodules/oracle/access'
  include PuppetX::EnterpriseModules::Oracle::Access

  # Create directory in database:
  directory_name = 'EXTRACT_DATA_DP'
  result = sql("create or replace directory #{directory_name} as '#{directory}'", { :sid => sid })
  puts({ :step => 'create directory', :status => 'success', :output => result }.to_json)

  # Export database
  connect_string = if database_user.empty?
                     '/ as sysdba'
                   else
                     "#{database_user}/#{database_user_password}"
                   end
  dumpfile = "#{directory_name}_#{sid}.dmp"
  logfile = "impdp_#{directory_name}_#{sid}.log"
  environment = {}
  environment[:ORACLE_HOME] = oracle_home
  environment[:ORACLE_SID] = sid
  environment[:PATH] = "/usr/local/bin:/bin:/usr/bin:/usr/local/sbin:/usr/sbin:/sbin:#{oracle_home}/bin"
  command = "echo #{connect_string} | #{oracle_home}/bin/impdp directory=#{directory_name} dumpfile=#{dumpfile} logfile=#{logfile} full=yes"
  result = Puppet::Util::Execution.execute(command, :failonfail => true, :custom_environment => environment, :uid => os_user)
  puts({ :step => 'import', :status => 'success', :output => result }.to_json)

  # Remove the directory
  result = sql("drop directory #{directory_name}", { :sid => sid })
  puts({ :step => 'remove directory', :status => 'success', :output => result }.to_json)
rescue Puppet::Error => e
  puts({ :status => 'failure', :error => e.message }.to_json)
  exit 1
end
# rubocop:enable Style/FrozenStringLiteralComment
